==> wiki3_5_7dev2.zip: wiki3_5_7dev2/plugin/admin/Install.pm <==
############################################################
#
# ǽ̤󶡤ޤ
#
############################################################
package plugin::admin::Install;
use strict;

sub install {
	my $wiki = shift;
	
	$wiki->add_menu("",$wiki->config('script_name')."?action=LOGIN",0);
	$wiki->add_handler("LOGIN","plugin::admin::Login");
	
	$wiki->add_admin_menu("Ķ"         ,$wiki->config('script_name')."?action=ADMINCONFIG",999,
						  "FSWikiΤư˴ؤԤޤ");
	
	$wiki->add_admin_menu(""     ,$wiki->config('script_name')."?action=ADMINSTYLE" ,998,
						  "ɤ˴ؤԤޤ");
	
	$wiki->add_admin_menu("桼"       ,$wiki->config('script_name')."?action=ADMINUSER"  ,997,
						  "桼ɲáѹԤޤ");

	$wiki->add_admin_menu("ڡ"       ,$wiki->config('script_name')."?action=ADMINPAGE"  ,996,
						  "ڡ롢¡Ԥޤ");
	
	$wiki->add_admin_menu("ץ饰"   ,$wiki->config('script_name')."?action=ADMINPLUGIN",995,
						  "ץ饰̵ͭԤޤ");

	$wiki->add_admin_menu("Хåå" ,$wiki->config('script_name')."?action=ADMINBACKUP"    ,994,
						  "tarǥХååץեɤޤ");
	
	$wiki->add_admin_menu("å",$wiki->config('script_name')."?action=ADMINCACHE"  ,993,
						  "WikiڡΥå˴ؤԤޤ");
	
	$wiki->add_admin_menu("å" ,$wiki->config('script_name')."?action=ADMINLOG"   ,992,
						  "ե롢åեΥɤԤޤ");

	$wiki->add_admin_menu("ѥк" ,$wiki->config('script_name')."?action=ADMINSPAM"   ,991,
						  "ѥкѤԤޤ");

	$wiki->add_user_menu("ѥɤѹ",$wiki->config('script_name')."?action=ACCOUNT",500,
						 "ʬΥѥɤѹޤ");
	
	$wiki->add_admin_handler("ADMINPAGE"   ,"plugin::admin::AdminPageHandler");
	$wiki->add_admin_handler("ADMINLOG"    ,"plugin::admin::AdminLogHandler");
	$wiki->add_admin_handler("ADMINCONFIG" ,"plugin::admin::AdminConfigHandler");
	$wiki->add_admin_handler("ADMINUSER"   ,"plugin::admin::AdminUserHandler");
	$wiki->add_admin_handler("ADMINPLUGIN" ,"plugin::admin::AdminPluginHandler");
	$wiki->add_admin_handler("ADMINSTYLE"  ,"plugin::admin::AdminStyleHandler");
	$wiki->add_admin_handler("ADMINCACHE"  ,"plugin::admin::AdminCacheHandler");
	$wiki->add_admin_handler("ADMINBACKUP" ,"plugin::admin::AdminBackupHandler");
	$wiki->add_admin_handler("ADMINSPAM"   ,"plugin::admin::AdminSpamHandler");
	
	$wiki->add_user_handler("ACCOUNT","plugin::admin::AccountHandler");
	
	$wiki->add_editform_plugin("plugin::admin::PermissionForm",101);
	$wiki->add_admin_handler("CHANGE_PAGE_PERMISSION","plugin::admin::PermissionForm");
}

1;

==> wiki3_6_1.zip: wiki3_6_1/plugin/admin/Install.pm <==
############################################################
#
# ǽ̤󶡤ޤ
#
############################################################
package plugin::admin::Install;
use strict;

sub install {
	my $wiki = shift;
	
	$wiki->add_menu("",$wiki->config('script_name')."?action=LOGIN",0);
	$wiki->add_handler("LOGIN","plugin::admin::Login");
	
	$wiki->add_admin_menu("Ķ"         ,$wiki->config('script_name')."?action=ADMINCONFIG",999,
						  "FSWikiΤư˴ؤԤޤ");
	
	$wiki->add_admin_menu(""     ,$wiki->config('script_name')."?action=ADMINSTYLE" ,998,
						  "ɤ˴ؤԤޤ");
	
	$wiki->add_admin_menu("桼"       ,$wiki->config('script_name')."?action=ADMINUSER"  ,997,
						  "桼ɲáѹԤޤ");

	$wiki->add_admin_menu("ڡ"       ,$wiki->config('script_name')."?action=ADMINPAGE"  ,996,
						  "ڡ롢¡Ԥޤ");
	
	$wiki->add_admin_menu("ץ饰"   ,$wiki->config('script_name')."?action=ADMINPLUGIN",995,
						  "ץ饰̵ͭԤޤ");

#	$wiki->add_admin_menu("Хåå" ,$wiki->config('script_name')."?action=ADMINBACKUP"    ,994,
#						  "tarǥХååץեɤޤ");
	
	$wiki->add_admin_menu("å",$wiki->config('script_name')."?action=ADMINCACHE"  ,993,
						  "WikiڡΥå˴ؤԤޤ");
	
	$wiki->add_admin_menu("å" ,$wiki->config('script_name')."?action=ADMINLOG"   ,992,
						  "ե롢åեΥɤԤޤ");

	$wiki->add_admin_menu("ѥк" ,$wiki->config('script_name')."?action=ADMINSPAM"   ,991,
						  "ѥкѤԤޤ");

	$wiki->add_user_menu("ѥɤѹ",$wiki->config('script_name')."?action=ACCOUNT",500,
						 "ʬΥѥɤѹޤ");
	
	$wiki->add_admin_handler("ADMINPAGE"   ,"plugin::admin::AdminPageHandler");
	$wiki->add_admin_handler("ADMINLOG"    ,"plugin::admin::AdminLogHandler");
	$wiki->add_admin_handler("ADMINCONFIG" ,"plugin::admin::AdminConfigHandler");
	$wiki->add_admin_handler("ADMINUSER"   ,"plugin::admin::AdminUserHandler");
	$wiki->add_admin_handler("ADMINPLUGIN" ,"plugin::admin::AdminPluginHandler");
	$wiki->add_admin_handler("ADMINSTYLE"  ,"plugin::admin::AdminStyleHandler");
	$wiki->add_admin_handler("ADMINCACHE"  ,"plugin::admin::AdminCacheHandler");
#	$wiki->add_admin_handler("ADMINBACKUP" ,"plugin::admin::AdminBackupHandler");
	$wiki->add_admin_handler("ADMINSPAM"   ,"plugin::admin::AdminSpamHandler");
	
	$wiki->add_user_handler("ACCOUNT","plugin::admin::AccountHandler");
	
	$wiki->add_editform_plugin("plugin::admin::PermissionForm",101);
	$wiki->add_admin_handler("CHANGE_PAGE_PERMISSION","plugin::admin::PermissionForm");
}

1;
